from ...__templates__.styles import Styles


class Justify(Styles):
    def __init__(self, senior):
        super().__init__(senior, [
            'align_items_start',
            'align_items_end',
            'align_items_center',
            'align_items_baseline',
            'align_items_stretch',
            'align_items_sm_start',
            'align_items_sm_end',
            'align_items_sm_center',
            'align_items_sm_baseline',
            'align_items_sm_stretch',
            'align_items_md_start',
            'align_items_md_end',
            'align_items_md_center',
            'align_items_md_baseline',
            'align_items_md_stretch',
            'align_items_lg_start',
            'align_items_lg_end',
            'align_items_lg_center',
            'align_items_lg_baseline',
            'align_items_lg_stretch',
            'align_items_xl_start',
            'align_items_xl_end',
            'align_items_xl_center',
            'align_items_xl_baseline',
            'align_items_xl_stretch',
            'align_items_xxl_start',
            'align_items_xxl_end',
            'align_items_xxl_center',
            'align_items_xxl_baseline',
            'align_items_xxl_stretch',
        ])

    def set_align_items_start(self): self.set('align-items-start')

    def set_align_items_end(self): self.set('align-items-end')

    def set_align_items_center(self): self.set('align-items-center')

    def set_align_items_baseline(self): self.set('align-items-baseline')

    def set_align_items_stretch(self): self.set('align-items-stretch')

    def set_align_items_sm_start(self): self.set('align-items-sm-start')

    def set_align_items_sm_end(self): self.set('align-items-sm-end')

    def set_align_items_sm_center(self): self.set('align-items-sm-center')

    def set_align_items_sm_baseline(self): self.set('align-items-sm-baseline')

    def set_align_items_sm_stretch(self): self.set('align-items-sm-stretch')

    def set_align_items_md_start(self): self.set('align-items-md-start')

    def set_align_items_md_end(self): self.set('align-items-md-end')

    def set_align_items_md_center(self): self.set('align-items-md-center')

    def set_align_items_md_baseline(self): self.set('align-items-md-baseline')

    def set_align_items_md_stretch(self): self.set('align-items-md-stretch')

    def set_align_items_lg_start(self): self.set('align-items-lg-start')

    def set_align_items_lg_end(self): self.set('align-items-lg-end')

    def set_align_items_lg_center(self): self.set('align-items-lg-center')

    def set_align_items_lg_baseline(self): self.set('align-items-lg-baseline')

    def set_align_items_lg_stretch(self): self.set('align-items-lg-stretch')

    def set_align_items_xl_start(self): self.set('align-items-xl-start')

    def set_align_items_xl_end(self): self.set('align-items-xl-end')

    def set_align_items_xl_center(self): self.set('align-items-xl-center')

    def set_align_items_xl_baseline(self): self.set('align-items-xl-baseline')

    def set_align_items_xl_stretch(self): self.set('align-items-xl-stretch')

    def set_align_items_xxl_start(self): self.set('align-items-xxl-start')

    def set_align_items_xxl_end(self): self.set('align-items-xxl-end')

    def set_align_items_xxl_center(self): self.set('align-items-xxl-center')

    def set_align_items_xxl_baseline(self): self.set('align-items-xxl-baseline')

    def set_align_items_xxl_stretch(self): self.set('align-items-xxl-stretch')
