from ...__templates__.styles import Styles


class Justify(Styles):
    def __init__(self, senior):
        super().__init__(senior, [
            'align_self_start',
            'align_self_end',
            'align_self_center',
            'align_self_baseline',
            'align_self_stretch',
            'align_self_sm_start',
            'align_self_sm_end',
            'align_self_sm_center',
            'align_self_sm_baseline',
            'align_self_sm_stretch',
            'align_self_md_start',
            'align_self_md_end',
            'align_self_md_center',
            'align_self_md_baseline',
            'align_self_md_stretch',
            'align_self_lg_start',
            'align_self_lg_end',
            'align_self_lg_center',
            'align_self_lg_baseline',
            'align_self_lg_stretch',
            'align_self_xl_start',
            'align_self_xl_end',
            'align_self_xl_center',
            'align_self_xl_baseline',
            'align_self_xl_stretch',
            'align_self_xxl_start',
            'align_self_xxl_end',
            'align_self_xxl_center',
            'align_self_xxl_baseline',
            'align_self_xxl_stretch',
        ])

    def align_self_start(self): self.set('align-self-start')

    def align_self_end(self): self.set('align-self-end')

    def align_self_center(self): self.set('align-self-center')

    def align_self_baseline(self): self.set('align-self-baseline')

    def align_self_stretch(self): self.set('align-self-stretch')

    def align_self_sm_start(self): self.set('align-self-sm-start')

    def align_self_sm_end(self): self.set('align-self-sm-end')

    def align_self_sm_center(self): self.set('align-self-sm-center')

    def align_self_sm_baseline(self): self.set('align-self-sm-baseline')

    def align_self_sm_stretch(self): self.set('align-self-sm-stretch')

    def align_self_md_start(self): self.set('align-self-md-start')

    def align_self_md_end(self): self.set('align-self-md-end')

    def align_self_md_center(self): self.set('align-self-md-center')

    def align_self_md_baseline(self): self.set('align-self-md-baseline')

    def align_self_md_stretch(self): self.set('align-self-md-stretch')

    def align_self_lg_start(self): self.set('align-self-lg-start')

    def align_self_lg_end(self): self.set('align-self-lg-end')

    def align_self_lg_center(self): self.set('align-self-lg-center')

    def align_self_lg_baseline(self): self.set('align-self-lg-baseline')

    def align_self_lg_stretch(self): self.set('align-self-lg-stretch')

    def align_self_xl_start(self): self.set('align-self-xl-start')

    def align_self_xl_end(self): self.set('align-self-xl-end')

    def align_self_xl_center(self): self.set('align-self-xl-center')

    def align_self_xl_baseline(self): self.set('align-self-xl-baseline')

    def align_self_xl_stretch(self): self.set('align-self-xl-stretch')

    def align_self_xxl_start(self): self.set('align-self-xxl-start')

    def align_self_xxl_end(self): self.set('align-self-xxl-end')

    def align_self_xxl_center(self): self.set('align-self-xxl-center')

    def align_self_xxl_baseline(self): self.set('align-self-xxl-baseline')

    def align_self_xxl_stretch(self): self.set('align-self-xxl-stretch')
