CN_INTEGER_0_TO_9 = '零壹贰叁肆伍陆柒捌玖'
CN_POINTS_UNITS = '角分厘'
CN_DECIMAL_4S_UNITS = '万亿兆京垓秭穰沟涧正载极'
CN_DECIMAL_UNITS = '拾佰仟'

CN_CURRENCY_UNIT = "圆"
CN_POINT_NAME = '点'
CN_ONLY_NAME = '整'
CN_CNY_NAME = '人民币'
CN_USD_NAME = '美元'
CN_EUR_NAME = '欧元'
CN_MINUS = '负'

EN_CNY_NAME = 'Say Chinese Yuan'
EN_USD_NAME = 'Say U.S.Dollar'
EN_EUR_NAME = 'Say Euro'
EN_ONLY_NAME = 'Only'
EN_POINT_NAME = 'Point'
EN_AND_NAME = 'and'
EN_MINUS = 'Minus'


EN_INTEGER_0_TO_9 = ['Zero', 'One', 'Two', 'Three', 'Four', 'Five', 'Six', 'Seven', 'Eight', 'Nine']
EN_INTEGER_1NS = ['Ten', 'Eleven', 'Twelve', 'Thirteen', 'Fourteen', 'Fifteen', 'Sixteen', 'Seventeen',
                  'Eighteen', 'Nineteen']
EN_INTEGER_2NS = ['Twenty', 'Thirty', 'Forty', 'Fifty', 'Sixty', 'Seventy', 'Eighty', 'Ninety']
EN_HUNDRED_NAME = 'Hundred'
EN_DECIMAL_3S_UNITS = ['Thousand', 'Million', 'Billion', 'Trillion', 'Quadrillion', 'Quintillion', 'Sextillion',
                       'Septillion', 'Octillion', 'Nonillion', 'Decillion']
EN_POINTS_UNITS = ['Dime', 'Cent', 'Mill']
