from ...__templates__.styles import Styles


class Justify(Styles):
    def __init__(self, senior):
        super().__init__(senior, [
            'justify-content-start',
            'justify-content-end',
            'justify-content-center',
            'justify-content-between',
            'justify-content-around',
            'justify-content-evenly',
            'justify-content-sm-start',
            'justify-content-sm-end',
            'justify-content-sm-center',
            'justify-content-sm-between',
            'justify-content-sm-around',
            'justify-content-sm-evenly',
            'justify-content-md-start',
            'justify-content-md-end',
            'justify-content-md-center',
            'justify-content-md-between',
            'justify-content-md-around',
            'justify-content-md-evenly',
            'justify-content-lg-start',
            'justify-content-lg-end',
            'justify-content-lg-center',
            'justify-content-lg-between',
            'justify-content-lg-around',
            'justify-content-lg-evenly',
            'justify-content-xl-start',
            'justify-content-xl-end',
            'justify-content-xl-center',
            'justify-content-xl-between',
            'justify-content-xl-around',
            'justify-content-xl-evenly',
            'justify-content-xxl-start',
            'justify-content-xxl-end',
            'justify-content-xxl-center',
            'justify-content-xxl-between',
            'justify-content-xxl-around',
            'justify-content-xxl-evenly',
        ])

    def set_justify_content_start(self): self.set('justify_content_start')

    def set_justify_content_end(self): self.set('justify_content_end')

    def set_justify_content_center(self): self.set('justify_content_center')

    def set_justify_content_between(self): self.set('justify_content_between')

    def set_justify_content_around(self): self.set('justify_content_around')

    def set_justify_content_evenly(self): self.set('justify_content_evenly')

    def set_justify_content_sm_start(self): self.set('justify_content_sm_start')

    def set_justify_content_sm_end(self): self.set('justify_content_sm_end')

    def set_justify_content_sm_center(self): self.set('justify_content_sm_center')

    def set_justify_content_sm_between(self): self.set('justify_content_sm_between')

    def set_justify_content_sm_around(self): self.set('justify_content_sm_around')

    def set_justify_content_sm_evenly(self): self.set('justify_content_sm_evenly')

    def set_justify_content_md_start(self): self.set('justify_content_md_start')

    def set_justify_content_md_end(self): self.set('justify_content_md_end')

    def set_justify_content_md_center(self): self.set('justify_content_md_center')

    def set_justify_content_md_between(self): self.set('justify_content_md_between')

    def set_justify_content_md_around(self): self.set('justify_content_md_around')

    def set_justify_content_md_evenly(self): self.set('justify_content_md_evenly')

    def set_justify_content_lg_start(self): self.set('justify_content_lg_start')

    def set_justify_content_lg_end(self): self.set('justify_content_lg_end')

    def set_justify_content_lg_center(self): self.set('justify_content_lg_center')

    def set_justify_content_lg_between(self): self.set('justify_content_lg_between')

    def set_justify_content_lg_around(self): self.set('justify_content_lg_around')

    def set_justify_content_lg_evenly(self): self.set('justify_content_lg_evenly')

    def set_justify_content_xl_start(self): self.set('justify_content_xl_start')

    def set_justify_content_xl_end(self): self.set('justify_content_xl_end')

    def set_justify_content_xl_center(self): self.set('justify_content_xl_center')

    def set_justify_content_xl_between(self): self.set('justify_content_xl_between')

    def set_justify_content_xl_around(self): self.set('justify_content_xl_around')

    def set_justify_content_xl_evenly(self): self.set('justify_content_xl_evenly')

    def set_justify_content_xxl_start(self): self.set('justify_content_xxl_start')

    def set_justify_content_xxl_end(self): self.set('justify_content_xxl_end')

    def set_justify_content_xxl_center(self): self.set('justify_content_xxl_center')

    def set_justify_content_xxl_between(self): self.set('justify_content_xxl_between')

    def set_justify_content_xxl_around(self): self.set('justify_content_xxl_around')

    def set_justify_content_xxl_evenly(self): self.set('justify_content_xxl_evenly')

