from .a.core import A
from .body.core import Body
from .button.core import Button
from .div.core import Div
from .h1.core import H1
from .h2.core import H2
from .h3.core import H3
from .h4.core import H4
from .h5.core import H5
from .h6.core import H6
from .head.core import Head
from .html.core import Html
from .input_text.core import InputText
from .li.core import Li
from .link.core import Link
from .meta.core import Meta
from .nav.core import Nav
from .ol.core import Ol
from .script.core import Script
from .span.core import Span
from .table.core import Table
from .tbody.core import Tbody
from .td.core import Td
from .th.core import Th
from .thead.core import Thead
from .title.core import Title
from .tr.core import Tr
from .ul.core import Ul
